NumberPickerWidget class

Inheritance

Constructors

NumberPickerWidget({Key? key, Color triangleColor = const Color(0xffFB8C00), Color boxBackgroundColor = const Color(0xFFF3DFD2), Color numberColor = const Color(0xFFDCC1AE), Color selectedNumberColor = Colors.black, int minValue = 0, int maxValue = 99, int value = 0, ValueChanged<int>? onValueChanged, int itemCount = 5, int step = 1, double itemHeight = 76, double itemWidth = 124, Axis axis = Axis.vertical, TextStyle? textStyle, TextStyle? selectedTextStyle, bool haptics = true, TextMapper? textMapper, bool zeroPad = true, Decoration? decoration, bool infiniteLoop = true})
const

Properties

axis Axis
final
boxBackgroundColor Color
final
decoration Decoration?
final
haptics bool
final
hashCode int
The hash code for this object.
no setterinherited
infiniteLoop bool
final
itemCount int
final
itemHeight double
final
itemWidth double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue int
final
minValue int
final
numberColor Color
final
onValueChanged ValueChanged<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedNumberColor Color
final
selectedTextStyle TextStyle?
final
step int
final
textMapper TextMapper?
final
textStyle TextStyle?
final
triangleColor Color
final
value int
final
zeroPad bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NumberPickerWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited